#!/bin/sh

# install script for Deck-It


cur_dir=`pwd`
deckit_dir=`dirname $0`
cd $deckit_dir
deckit_dir=`pwd`
src_bin1=$deckit_dir/deckit.bin
src_bin2=$deckit_dir/wbmp.bin

usage () {
    echo "Usage:"
    echo "  $0 --help    Show this help"
    echo "  $0           Install scripts in Deck-It directory"
    echo "  $0 <dir>     Install scripts in <dir>"
    quit $1
}


quit () {
    cd $cur_dir
    exit $1
}


catch () {
    echo
    echo "*** installation aborted ***"
    cd $cur_dir
    exit 1
}


checklibs () {
    libs=`ldd $1 2>/dev/null | grep -v "libpt" | grep -i "not found"`
    if [ -n "$libs" ]
    then
	echo "The following libraries are missing to run deckit:"
	echo "$libs"
	quit 1
    fi
}

trap catch 1 2 15


case "$1" in
    -h|--h|-help|--help )
	usage 0
	;;
    "")
	install_dir=`pwd`
	;;
    *)
	install_dir=$1
	;;
esac


# Check binaries

[ ! -x $src_bin1 ] && echo "Can't find $src_bin1" && quit 1
[ ! -x $src_bin2 ] && echo "Can't find $src_bin2" && quit 1

checklibs $src_bin1
checklibs $src_bin2

# Check install directories

[ ! -d $install_dir ] && echo "Directory $install_dir does not exists" && quit 1
[ ! -w $install_dir ] && echo "You don't have write permission on $install_dir" && quit 1


dst_bin1=$install_dir/deckit
dst_bin2=$install_dir/wbmp


echo "Installing scripts in $install_dir"

if [ -f $dst_bin1 ]
then
    read -p "Overwrite $dst_bin1 ? [y/N] " rep
    [ "$rep" != "y" ] && quit 0
fi

if [ -f $dst_bin2 ]
then
    read -p "Overwrite $dst_bin2 ? [y/N] " rep
    [ "$rep" != "y" ] && quit 0
fi

echo "Creating $dst_bin1"

cat <<EOF > $dst_bin1
#!/bin/sh

LD_LIBRARY_PATH=$deckit_dir $src_bin1

EOF

chmod +x $dst_bin1

echo "Creating $dst_bin2"

cat <<EOF > $dst_bin2
#!/bin/sh

LD_LIBRARY_PATH=$deckit_dir $src_bin2

EOF

chmod +x $dst_bin2

